###############################################################################
#	Filename:	Saffi.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Saffi Larsen, XO, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#NonSerializedObjects = ( "debug", )

#debug = App.CPyDebug(__name__).Print

###############################################################################
#	CreateCharacter()
#
#	Create Saffi by building her character and placing her on the passed in set.
#	Create her menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	debug("Creating Saffi")

	if (pSet.GetObject("XO") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("XO")))
	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/borgqueen/borgqueen_head.nif", None)
	pNxSaffi = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", CharacterPaths.g_pcHeadNIFPath + "../BridgeCrew/borgqueen/borgqueen_head.nif", 1)
	pNxSaffi.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/borgqueen/borgqueen_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")

	pNxSaffi.SetCharacterName("Saffi")

	# Add the character to the set
	pSet.AddObjectToSet(pNxSaffi, "XO")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pNxSaffi)

	# Setup the character configuration
	pNxSaffi.SetSize(App.CharacterClass.MEDIUM)
	pNxSaffi.SetGender(App.CharacterClass.FEMALE)
	pNxSaffi.SetRandomAnimationChance(.75)
	pNxSaffi.SetBlinkChance(0.1)
	pNxSaffi.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Saffi's general dialogue lines.
	LoadSounds()

	pNxSaffi.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.SetBlinkStages(3)

	pNxSaffi.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pNxSaffi.SetAnimatedSpeaking(1)

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pNxSaffi.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Commander")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	debug("Finished creating Saffi")
	return pNxSaffi


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pNxSaffi = App.CharacterClass_Cast(pSet.GetObject("XO"))
	if (pNxSaffi == None):
#		debug("******* Commanding officer not found *********")
		return

#	debug("Attaching menu to XO..")
	import Bridge.XOCharacterHandlers
	Bridge.XOCharacterHandlers.AttachMenuToXO(pNxSaffi)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Main power back on line"
	#

###############################################################################
#	ConfigureForNx()
#
#	Configure ourselves for the Sovereign bridge
#
#	Args:	pNxSaffi	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForNx(pNxSaffi):
#	debug("Configuring Saffi for the Nx bridge")

	# Clear out any old animations from another configuration
	pNxSaffi.ClearAnimations()

	# Register animation mappings
	pNxSaffi.AddAnimation("SeatedNxCommander", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("StandingNxCommander", "Bridge.Characters.CommonAnimations.Standing")
	pNxSaffi.AddAnimation("EBL1MToEBCommander", "Bridge.Characters.NxMediumAnimations.EBMoveFromL1ToC")
	pNxSaffi.AddAnimation("EBCommanderToL1", "Bridge.Characters.NxMediumAnimations.EBMoveFromCToL1")
	pNxSaffi.AddAnimation("EBCommanderToC1", "Bridge.Characters.NxMediumAnimations.EBMoveFromCToC1")
	pNxSaffi.AddAnimation("EBCommander1ToC", "Bridge.Characters.NxMediumAnimations.EBMoveFromC1ToC")
	pNxSaffi.AddAnimation("NxCommanderTurnCaptain", "Bridge.Characters.NxMediumAnimations.NxTurnAtCTowardsCaptain")
	pNxSaffi.AddAnimation("NxCommanderBackCaptain", "Bridge.Characters.NxMediumAnimations.NxTurnBackAtCFromCaptain")

	pNxSaffi.AddAnimation("NxCommanderGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceRight")
	pNxSaffi.AddAnimation("NxCommanderGlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("NxCommander1GlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceRight")
	pNxSaffi.AddAnimation("NxCommander1GlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedM")

	pNxSaffi.AddAnimation("EBCommanderTurnE", "Bridge.Characters.NxMediumAnimations.EBCTalkE")
	pNxSaffi.AddAnimation("EBCommanderBackE", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("EBCommanderTurnH", "Bridge.Characters.NxMediumAnimations.EBCTalkH")
	pNxSaffi.AddAnimation("EBCommanderBackH", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("EBCommanderTurnT", "Bridge.Characters.NxMediumAnimations.EBCTalkT")
	pNxSaffi.AddAnimation("EBCommanderBackT", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("EBCommanderTurnS", "Bridge.Characters.NxMediumAnimations.EBCTalkS")
	pNxSaffi.AddAnimation("EBCommanderBackS", "Bridge.Characters.CommonAnimations.SeatedM")

	pNxSaffi.AddAnimation("EBCommanderTurnX", "Bridge.Characters.NxMediumAnimations.EBCTalkE")
	pNxSaffi.AddAnimation("EBCommanderBackX", "Bridge.Characters.CommonAnimations.SeatedM")

	# Breathing
	pNxSaffi.AddAnimation("NxCommanderBreathe", "Bridge.Characters.CommonAnimations.SeatedM")
	pNxSaffi.AddAnimation("NxCommander1Breathe", "Bridge.Characters.CommonAnimations.Standing")
	pNxSaffi.AddAnimation("NxCommanderBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")
	pNxSaffi.AddAnimation("NxCommander1BreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Interaction
	pNxSaffi.AddRandomAnimation("Bridge.Characters.NxMediumAnimations.NxCConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)
	pNxSaffi.AddAnimation("PushingButtons", "Bridge.Characters.NxMediumAnimations.NxCConsoleInteraction")

	# Hit animations
	pNxSaffi.AddAnimation("NxCommanderHit", "Bridge.Characters.NxMediumAnimations.NxCHit")
	pNxSaffi.AddAnimation("NxCommanderHitHard", "Bridge.Characters.NxMediumAnimations.NxCHitHard")
	#pNxSaffi.AddAnimation("EBCommanderHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	#pNxSaffi.AddAnimation("EBCommanderHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pNxSaffi.AddAnimation("NxCommanderReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pNxSaffi.AddAnimation("NxCommanderReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	# Add common animations.
	AddCommonAnimations(pNxSaffi)
	pNxSaffi.SetStanding(0)
	pNxSaffi.SetLocation("NxCommander")
	pNxSaffi.AddPositionZoom("NxCommander", 0.9)
#	debug("Finished configuring Saffi")

###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pNxSaffi	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pNxSaffi):
	pNxSaffi.AddRandomAnimation("Bridge.Characters.NxMediumAnimations.CLookAroundConsoleDown", App.CharacterClass.SITTING_ONLY, 1, 1)

	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft", App.CharacterClass.SITTING_ONLY)
	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight", App.CharacterClass.SITTING_ONLY)
	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp", App.CharacterClass.SITTING_ONLY)
	pNxSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown", App.CharacterClass.SITTING_ONLY)

###############################################################################
#	LoadSounds
#	
#	Load any of Saffi's general or spontaneous sounds, so they don't
#	hitch the game when they're played.
#	
#	Args:	None
#	
#	Return:	None
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")
	
	#
	# Build a list of sound to load
	#
	lSoundList =	[
		# Yes?
		"gf001",
		"gf002",

		# Report.
		"gf020",

		# Alert lines.
		"GreenAlert",
		"GreenAlert2",
		"GreenAlert3",
		"YellowAlert",
		"YellowAlert3",
		"YellowAlert2",
		"RedAlert",
		"RedAlert2",

		# Contacting starfleet.
		"gl004",
		"gl005",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for sLine in lSoundList:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
