###############################################################################
#	Filename:	Kiska.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Kiska Lomar, Helm, and configures animations
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Kiska by building her character and placing her on the passed in set.
#	Create her menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating NxKiska")

	if (pSet.GetObject("Helm") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Helm")))

	CharacterPaths.UpdatePaths()
	# Create the character

	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadSaffi/saffi_head.nif", None)
	pNxPDWKiska = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", CharacterPaths.g_pcHeadNIFPath + "HeadSaffi/saffi_head.nif", 1)
	pNxPDWKiska.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Saffi/saffi_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head.tga")

	pNxPDWKiska.SetCharacterName("Kiska")

	# Add the character to the set
	pSet.AddObjectToSet(pNxPDWKiska, "Helm")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pNxPDWKiska)

	# Setup the character configuration
	pNxPDWKiska.SetSize(App.CharacterClass.MEDIUM)
	pNxPDWKiska.SetGender(App.CharacterClass.FEMALE)
	pNxPDWKiska.SetStanding(0)
	pNxPDWKiska.SetRandomAnimationChance(0.75)
	pNxPDWKiska.SetBlinkChance(0.1)
	pNxPDWKiska.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Helm officer generic sounds
	LoadSounds()

	pNxPDWKiska.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_blink1.tga")
	pNxPDWKiska.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_blink2.tga")
	pNxPDWKiska.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_eyesclosed.tga")
	pNxPDWKiska.SetBlinkStages(3)

	pNxPDWKiska.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_a.tga")
	pNxPDWKiska.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_e.tga")
	pNxPDWKiska.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_u.tga")
	pNxPDWKiska.SetAnimatedSpeaking(1)

	pGame = App.Game_GetCurrentGame()
	pGame.LoadDatabaseSoundInGroup(pNxPDWKiska.GetDatabase(), "KiskaNothingToAdd", "BridgeGeneric")

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pNxPDWKiska.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Helm")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	kDebugObj.Print("Finished creating NxKiska")
	return pNxPDWKiska


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pNxPDWKiska = App.CharacterClass_Cast(pSet.GetObject("Helm"))
	if (pNxPDWKiska == None):
#		kDebugObj.Print("******* Helm officer not found *********")
		return

#	kDebugObj.Print("Attaching menu to Helm..")
	import Bridge.HelmCharacterHandlers
	Bridge.HelmCharacterHandlers.AttachMenuToHelm(pNxPDWKiska)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Orbiting planet"
	#


###############################################################################
#	ConfigureForNx()
#
#	Configure ourselves for the Nx bridge
#
#	Args:	pNxPDWKiska	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForNx(pNxPDWKiska):
#	kDebugObj.Print("Configuring NxKiska for the Nx bridge")

	# Clear out any old animations from another configuration
	pNxPDWKiska.ClearAnimations()

	# Register animation mappings
	pNxPDWKiska.AddAnimation("NxHelmTurnCaptain", "Bridge.Characters.NxPDWMediumAnimations.NxTurnAtHTowardsCaptain")
	pNxPDWKiska.AddAnimation("NxHelmBackCaptain", "Bridge.Characters.NxPDWMediumAnimations.NxTurnBackAtHFromCaptain")


	pNxPDWKiska.AddAnimation("NxHelmGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceRight")
	pNxPDWKiska.AddAnimation("NxHelmGlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedM")

	# Breathing
	pNxPDWKiska.AddAnimation("EBHelmBreathe", "Bridge.Characters.CommonAnimations.SeatedM")

	# Nxeraction
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.NxPDWMediumAnimations.EBHConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pNxPDWKiska.AddAnimation("PushingButtons", "Bridge.Characters.NxPDWMediumAnimations.EBHConsoleInteraction")

	# Hit animations
	#pNxPDWKiska.AddAnimation("NxHelmHit", "Bridge.Characters.NxPDWMediumAnimations.NxHHit")
	#pNxPDWKiska.AddAnimation("NxHelmHitHard", "Bridge.Characters.NxPDWMediumAnimations.NxHHitHard")
	pNxPDWKiska.AddAnimation("NxHelmReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pNxPDWKiska.AddAnimation("NxHelmReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	# Add common animations.
	AddCommonAnimations(pNxPDWKiska)

	pNxPDWKiska.SetLocation("NxHelm")
	pNxPDWKiska.SetLookAtAdj(30, 0, 45)
	pNxPDWKiska.AddPositionZoom("NxHelm", 0.95, "Helm")
#	kDebugObj.Print("Finished configuring NxKiska")


###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pNxPDWKiska	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pNxPDWKiska):
	# Nxeraction with their environment
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.NxPDWMediumAnimations.HLookAroundConsoleDown", App.CharacterClass.SITTING_ONLY, 1, 1)

	# Just random stuff
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")

	# These look bad
	#pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowLeft")
	#pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowRight")

	# These force the arms up
	#pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	#pNxPDWKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")

###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")

	#
	# Build a list of sound to load
	#
	lSoundList =	[	"KiskaSir1",	# Click Response
						"KiskaSir2",
						"KiskaSir3",
						"KiskaSir4",
						"KiskaSir5",
						
						"KiskaYes1",	# Order Confirmation
						"KiskaYes2",
						"KiskaYes3",
						"KiskaYes4",

						"gh075",	# Course laid in
						"gh081",	# Nxercept course plotted

						"HailOpen1",
						"HailOpen2",
						"NotResponding1",
						"NotResponding2",
						"OnScreen",

						"CollisionAlert1",
						"CollisionAlert2",
						"CollisionAlert3",
						"CollisionAlert4",
						"CollisionAlert5",
						"CollisionAlert6",
						"CollisionAlert7",
						"CollisionAlert10",

						"IncomingMsg1",
						"IncomingMsg2",
						"IncomingMsg3",
						"IncomingMsg4",
						"IncomingMsg5",
						"IncomingMsg6",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for sLine in lSoundList:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
