###############################################################################
#	Filename:	NxMaleExtra2.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Ambassador NxMaleExtra2, and configures animations.
#	
#	Created:	10/03/00 -	CCarley
###############################################################################

import App
import CharacterPaths

#kDNxugObj = App.CPyDNxug()

###############################################################################
#	CreateCharacter()
#
#	Create NxMaleExtra2 by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDNxugObj.Print("Creating NxMaleExtra2")

	if (pSet.GetObject("NxMaleExtra2") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("MaleExtra2")))

	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyNxMaleM/BodyNxMaleM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/Miguel_head.nif", None)
	pNxMaleExtra2 = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyNxMaleM/BodyNxMaleM.nif", CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/Miguel_head.nif")
	pNxMaleExtra2.ReplacNxodyAndHead(CharacterPaths.g_pcBodyTexPath + "BodyNxMaleM/FedGold_body.tga", CharacterPaths.g_pcHeadTexPath + "HeadMiguel/NxMale_ensignB_head.tga")

	# Add the character to the set
	pSet.AddObjectToSet(pNxMaleExtra2, "MaleExtra2")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pNxMaleExtra2)

	# Setup the character configuration
	pNxMaleExtra2.SetSize(App.CharacterClass.MEDIUM)
	pNxMaleExtra2.SetGender(App.CharacterClass.Male)
	pNxMaleExtra2.SetRandomAnimationChance(.75)
	pNxMaleExtra2.SetBlinkChance(0.1)
	pNxMaleExtra2.SetCharacterName("MaleExtra2")

	pNxMaleExtra2.SetHidden(1)

	# Load NxMaleExtra2's generic sounds
	LoadSounds()

	# Create NxMaleExtra2's menus
	#import NxMaleExtra2MenuHandlers
	#NxMaleExtra2MenuHandlers.CreateMenus(pNxMaleExtra2)

	pNxMaleExtra2.SetDatabase("data/TGL/Bridge Crew General.tgl")

	pGame = App.Game_GetCurrentGame()
	#pGame.LoadDatabaseSoundInGroup(pNxMaleExtra2.GetDatabase(), "NxMaleExtra2NothingToAdd", "BridgeGeneric")

#	kDNxugObj.Print("Finished creating NxMaleExtra2")
	return pNxMaleExtra2

###############################################################################
#	ConfigureForGalaxy()
#
#	Configure ourselves for the Galaxy bridge
#
#	Args:	pNxMaleExtra2	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForGalaxy(pNxMaleExtra2):
#	kDNxugObj.Print("Configuring NxMaleExtra2 for the Galaxy bridge")

	# Clear out any old animations from another configuration
	pNxMaleExtra2.ClearAnimations()

	#
	# *** CURRENTLY NxMaleExtra2 HAS NO GALAXY CLASS ANIMATIONS ***
	#

	# Add common animations.
	AddCommonAnimations(pNxMaleExtra2)

	pNxMaleExtra2.SetAsExtra(1)
	pNxMaleExtra2.SetHidden(1)

	pNxMaleExtra2.SetLocation("DBL2M")
#	kDNxugObj.Print("Finished configuring NxMaleExtra2")


###############################################################################
#	ConfigureForNx()
#
#	Configure ourselves for the Nx bridge
#
#	Args:	pNxMaleExtra2	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForNx(pNxMaleExtra2):
#	kDNxugObj.Print("Configuring NxMaleExtra2 for the Nx bridge")

	# Clear out any old animations from another configuration
	pNxMaleExtra2.ClearAnimations()

	# Register animation mappings
	pNxMaleExtra2.AddAnimation("NxL2MToG", "Bridge.Characters.NxPDWMediumAnimations.NxL2ToG2")
	pNxMaleExtra2.AddAnimation("NxG2MToL", "Bridge.Characters.NxPDWMediumAnimations.NxG2ToL2")
	pNxMaleExtra2.AddAnimation("StandingNxG2M", "Bridge.Characters.CommonAnimations.Standing")
	pNxMaleExtra2.SetStanding(1)

	# Hit animations
	pNxMaleExtra2.AddAnimation("NxG2MHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	pNxMaleExtra2.AddAnimation("NxG2MHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pNxMaleExtra2.AddAnimation("NxG2MReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pNxMaleExtra2.AddAnimation("NxG2MReactRight", "Bridge.Characters.CommonAnimations.ReactRight")
	pNxMaleExtra2.AddAnimation("NxG2MFly", "Bridge.Characters.CommonAnimations.Blast")

	pNxMaleExtra2.SetAsExtra(1)
	pNxMaleExtra2.SetHidden(1)

	# Add common animations.
	AddCommonAnimations(pNxMaleExtra2)

	pNxMaleExtra2.SetLocation("NxL2M")
#	kDNxugObj.Print("Finished configuring NxMaleExtra2")


###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pNxMaleExtra2	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pNxMaleExtra2):
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.HitCommunicator")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsoleDown")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsoleUp")
	pNxMaleExtra2.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsole")
	
###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	#
	# NxMaleExtra2 has no generic bridge sounds at this time
	#
	pass
