###############################################################################
#	Filename:	NxMaleExtra3.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Ambassador NxMaleExtra3, and configures animations.
#	
#	Created:	10/03/00 -	CCarley
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDNxug()

###############################################################################
#	CreateCharacter()
#
#	Create NxMaleExtra3 by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating NxMaleExtra3")

	if (pSet.GetObject("NxMaleExtra3") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("MaleExtra3")))

	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyNxMaleM/BodyNxMaleM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadData/Data_head.nif", None)
	pNxMaleExtra3 = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyNxMaleM/BodyNxMaleM.nif", CharacterPaths.g_pcHeadNIFPath + "HeadData/Data_head.nif")
	pNxMaleExtra3.ReplacNxodyAndHead(CharacterPaths.g_pcBodyTexPath + "BodyNxMaleM/FedGold_body.tga", CharacterPaths.g_pcHeadTexPath + "HeadData/NxMale_ensignC_head.tga")

	# Add the character to the set
	pSet.AddObjectToSet(pNxMaleExtra3, "MaleExtra3")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pNxMaleExtra3)

	# Setup the character configuration
	pNxMaleExtra3.SetSize(App.CharacterClass.MEDIUM)
	pNxMaleExtra3.SetGender(App.CharacterClass.Male)
	pNxMaleExtra3.SetRandomAnimationChance(.75)
	pNxMaleExtra3.SetBlinkChance(0.1)
	pNxMaleExtra3.SetCharacterName("MaleExtra3")

	pNxMaleExtra3.SetHidden(1)

	# Load NxMaleExtra3's generic sounds
	LoadSounds()

	# Create NxMaleExtra3's menus
	#import NxMaleExtra3MenuHandlers
	#NxMaleExtra3MenuHandlers.CreateMenus(pNxMaleExtra3)

	pNxMaleExtra3.SetDatabase("data/TGL/Bridge Crew General.tgl")

	pGame = App.Game_GetCurrentGame()
	#pGame.LoadDatabaseSoundInGroup(pNxMaleExtra3.GetDatabase(), "NxMaleExtra3NothingToAdd", "BridgeGeneric")

#	kDebugObj.Print("Finished creating NxMaleExtra3")
	return pNxMaleExtra3

###############################################################################
#	ConfigureForGalaxy()
#
#	Configure ourselves for the Galaxy bridge
#
#	Args:	pNxMaleExtra3	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForGalaxy(pNxMaleExtra3):
#	kDebugObj.Print("Configuring NxMaleExtra3 for the Galaxy bridge")

	# Clear out any old animations from another configuration
	pNxMaleExtra3.ClearAnimations()

	#
	# *** CURRENTLY NxMaleExtra3 HAS NO GALAXY CLASS ANIMATIONS ***
	#

	# Add common animations.
	AddCommonAnimations(pNxMaleExtra3)

	pNxMaleExtra3.SetAsExtra(1)
	pNxMaleExtra3.SetHidden(1)

	pNxMaleExtra3.SetLocation("DBL1M")
#	kDebugObj.Print("Finished configuring NxMaleExtra3")

###############################################################################
#	ConfigureForNx()
#
#	Configure ourselves for the Sovereign bridge
#
#	Args:	pMaleExtra3	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForNx(pNxMaleExtra3):
#	kDebugObj.Print("Configuring MaleExtra3 for the Sovereign bridge")

	# Clear out any old animations from another configuration
	pNxMaleExtra3.ClearAnimations()

	# Register animation mappings
	pNxMaleExtra3.AddAnimation("NxL1MToG", "Bridge.Characters.NxPDWMediumAnimations.NxL1ToG3")
	pNxMaleExtra3.AddAnimation("NxG3MToL", "Bridge.Characters.NxPDWMediumAnimations.NxG3ToL1")
	pNxMaleExtra3.AddAnimation("StandingNxG3M", "Bridge.Characters.CommonAnimations.Standing")
	pNxMaleExtra3.SetStanding(1)

	# Hit animations
	pNxMaleExtra3.AddAnimation("NxG3MHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	pNxMaleExtra3.AddAnimation("NxG3MHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pNxMaleExtra3.AddAnimation("NxG3MReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pNxMaleExtra3.AddAnimation("NxG3MReactRight", "Bridge.Characters.CommonAnimations.ReactRight")
	pNxMaleExtra3.AddAnimation("NxG3MFly", "Bridge.Characters.CommonAnimations.Blast2")

	pNxMaleExtra3.SetAsExtra(1)
	pNxMaleExtra3.SetHidden(1)

	# Add common animations.
	AddCommonAnimations(pNxMaleExtra3)

	pNxMaleExtra3.SetLocation("NxL1M")
#	kDebugObj.Print("Finished configuring MaleExtra3")


###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pNxMaleExtra3	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pNxMaleExtra3):
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.HitCommunicator")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsoleDown")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsoleUp")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsole")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.NxPDWMediumAnimations.NxExtraConsoleInteraction")
	pNxMaleExtra3.AddRandomAnimation("Bridge.Characters.NxPDWMediumAnimations.NxExtraConsoleInteraction")


###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	#
	# NxMaleExtra3 has no generic bridge sounds at this time
	#
	pass
