###############################################################################
#	Filename:	Miguel.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Miguel Diaz, science, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Miguel by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating Miguel")

	if (pSet.GetObject("Science") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Science")))


	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleS/BodyMaleS.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/miguel_head.nif", None)
	pNxPDWMiguel = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleS/BodyMaleS.nif", CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/miguel_head.nif")
	pNxPDWMiguel.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Miguel/miguel_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/miguel_head.tga")

	pNxPDWMiguel.SetCharacterName("Miguel")

	# Add the character to the set
	pSet.AddObjectToSet(pNxPDWMiguel, "Science")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pNxPDWMiguel)

	# Setup the character configuration
	pNxPDWMiguel.SetSize(App.CharacterClass.SMALL)
	pNxPDWMiguel.SetGender(App.CharacterClass.MALE)
	pNxPDWMiguel.SetRandomAnimationChance(.75)
	pNxPDWMiguel.SetBlinkChance(0.1)
	pNxPDWMiguel.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Science officer generic sounds
	LoadSounds()

	pNxPDWMiguel.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_blink1.tga")
	pNxPDWMiguel.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_blink2.tga")
	pNxPDWMiguel.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_eyesclosed.tga")
	pNxPDWMiguel.SetBlinkStages(3)

	pNxPDWMiguel.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_a.tga")
	pNxPDWMiguel.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_e.tga")
	pNxPDWMiguel.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_u.tga")
	pNxPDWMiguel.SetAnimatedSpeaking(1)

	pGame = App.Game_GetCurrentGame()
	pGame.LoadDatabaseSoundInGroup(pNxPDWMiguel.GetDatabase(), "MiguelNothingToAdd", "BridgeGeneric")

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pNxPDWMiguel.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Science")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	kDebugObj.Print("Finished creating Miguel")
	return pNxPDWMiguel


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pNxPDWMiguel = App.CharacterClass_Cast(pSet.GetObject("Science"))
	if (pNxPDWMiguel == None):
#		kDebugObj.Print("******* Science officer not found *********")
		return

#	kDebugObj.Print("Attaching menu to Science..")
	import Bridge.ScienceCharacterHandlers
	Bridge.ScienceCharacterHandlers.AttachMenuToScience(pNxPDWMiguel)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Receiving probe data"
	#

###############################################################################
#	ConfigureForNx()
#
#	Configure ourselves for the Nx bridge
#
#	Args:	pNxPDWMiguel	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForNx(pNxPDWMiguel):
#	kDebugObj.Print("Configuring Miguel for the Nx bridge")

	# Clear out any old animations from another configuration
	pNxPDWMiguel.ClearAnimations()

	# Register animation mappings
	pNxPDWMiguel.AddAnimation("EBL1SToS", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromL1ToS")
	pNxPDWMiguel.AddAnimation("EBScienceToL1", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromSToL1")
	pNxPDWMiguel.AddAnimation("NxScienceTurnCaptain", "Bridge.Characters.NxPDWSmallAnimations.NxTurnAtSTowardsCaptain")
	pNxPDWMiguel.AddAnimation("NxScienceBackCaptain", "Bridge.Characters.NxPDWSmallAnimations.NxTurnBackAtSFromCaptain")

	pNxPDWMiguel.AddAnimation("NxScienceTurnC", "Bridge.Characters.NxPDWSmallAnimations.NxTurnAtSTowardsCaptain")
	pNxPDWMiguel.AddAnimation("NxScienceBackC", "Bridge.Characters.CommonAnimations.SeatedS")
	pNxPDWMiguel.AddAnimation("NxScienceTurnH", "Bridge.Characters.NxPDWSmallAnimations.EBSTalkH")
	pNxPDWMiguel.AddAnimation("NxScienceBackH", "Bridge.Characters.CommonAnimations.SeatedS")
	pNxPDWMiguel.AddAnimation("NxScienceTurnE", "Bridge.Characters.NxPDWSmallAnimations.EBSTalkE")
	pNxPDWMiguel.AddAnimation("NxScienceBackE", "Bridge.Characters.CommonAnimations.SeatedS")
	pNxPDWMiguel.AddAnimation("NxScienceTurnT", "Bridge.Characters.NxPDWSmallAnimations.EBSTalkT")
	pNxPDWMiguel.AddAnimation("NxScienceBackT", "Bridge.Characters.CommonAnimations.SeatedS")

	pNxPDWMiguel.AddAnimation("NxScienceTurnX", "Bridge.Characters.NxPDWSmallAnimations.EBSTalkE")
	pNxPDWMiguel.AddAnimation("NxScienceBackX", "Bridge.Characters.CommonAnimations.SeatedS")

	pNxPDWMiguel.AddAnimation("NxScienceGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceRight")
	pNxPDWMiguel.AddAnimation("NxScienceGlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedS")

	pNxPDWMiguel.AddAnimation("EBScienceToS1", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromSToS1")
	pNxPDWMiguel.AddAnimation("EBScience1ToS", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromS1ToS")
	pNxPDWMiguel.AddAnimation("EBScienceToS2", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromSToS2")
	pNxPDWMiguel.AddAnimation("EBScience2ToS", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromS2ToS")
	pNxPDWMiguel.AddAnimation("EBScience1ToS2", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromS1ToS2")
	pNxPDWMiguel.AddAnimation("EBScience2ToS1", "Bridge.Characters.NxPDWSmallAnimations.EBMoveFromS2ToS1")

	# Breathing	
	pNxPDWMiguel.AddAnimation("NxScienceBreathe", "Bridge.Characters.CommonAnimations.SeatedS")
	pNxPDWMiguel.AddAnimation("NxScienceBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Interaction
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.NxPDWSmallAnimations.NxSConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pNxPDWMiguel.AddAnimation("PushingButtons", "Bridge.Characters.NxPDWSmallAnimations.NxSConsoleInteraction")

	# Hit animations
	pNxPDWMiguel.AddAnimation("NxScienceHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	pNxPDWMiguel.AddAnimation("NxScienceHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pNxPDWMiguel.AddAnimation("NxScienceReactLeftStanding", "Bridge.Characters.CommonAnimations.ReactLeft");
	pNxPDWMiguel.AddAnimation("NxScienceReactRightStanding", "Bridge.Characters.CommonAnimations.ReactRight");

	# Add common animations.
	AddCommonAnimations(pNxPDWMiguel)

	# Miguel stamds on the Nx bridge
	pNxPDWMiguel.SetLocation("NxScience")
	pNxPDWMiguel.SetStanding(0)
	pNxPDWMiguel.SetLookAtAdj(130, 0, 50)
	pNxPDWMiguel.AddPositionZoom("NxScience", 0.8, "Science")
#	kDebugObj.Print("Finished configuring Miguel")



###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pNxPDWMiguel	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pNxPDWMiguel):
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.NxPDWSmallAnimations.SLookAroundConsoleDown", App.CharacterClass.SITTING_ONLY, 1, 1)

	#pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowLeft")
	#pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowRight")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	pNxPDWMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.Nod", App.CharacterClass.STANDING_ONLY)


###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")
	# Like a function pointer (GetFile() is the same as pDatabase.GetFilename())
	GetFile = pDatabase.GetFilename	# do this for horizontal space savings

	#
	# Build a list of sound to load
	#
	kSoundList =	[	"MiguelSir1",		# Click Response
						"MiguelSir2",
						"MiguelSir3",
						"MiguelSir4",
						"MiguelSir5",

						"MiguelYes1",		# Order Confirmation
						"MiguelYes2",
						"MiguelYes3",
						"MiguelYes4",

						# Scanning lines.
						"MiguelScan",
						"gs038",
						"gs039",
						"gs040",
						"gs041",

						# Launching a probe.
						"gs030",

						# Spontaneous shield callouts.
						"TargetFrontShieldFailed",
						"TargetFrontShieldDraining",
						"TargetRearShieldFailed",
						"TargetRearShieldDraining",
						"TargetLeftShieldFailed",
						"TargetLeftShieldDraining",
						"TargetRightShieldFailed",
						"TargetRightShieldDraining",
						"TargetTopShieldFailed",
						"TargetTopShieldDraining",
						"TargetBottomShieldFailed",
						"TargetBottomShieldDraining",

						# Spontaneous target system callouts..
						"TargetHull05",
						"TargetHull10",
						"TargetHull15",
						"TargetHull20",
						"TargetHull25",
						"TargetHull50",
						"TargetHull75",

						"TargetPhasersDisabled",
						"TargetShieldsDisabled",
						"TargetSensorsDisabled",
						"TargetTorpedoesDisabled",
						"TargetTractorDisabled",
						"TargetImpulseDisabled",
						"TargetWarpDisabled",

						"TargetPhasersDestroyed",
						"TargetShieldsDestroyed",
						"TargetSensorsDestroyed",
						"TargetTorpedoesDestroyed",
						"TargetTractorDestroyed",
						"TargetImpulseDestroyed",
						"TargetWarpDestroyed",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for i in range(len(kSoundList)):
		pGame.LoadDatabaseSoundInGroup(pDatabase, kSoundList[i], "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
